#line 2 "lex.yy.c"

#line 4 "lex.yy.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 36
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE _mesa_program_restart(yyin ,yyscanner )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via _mesa_program_restart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void _mesa_program_restart (FILE *input_file ,yyscan_t yyscanner );
void _mesa_program__switch_to_buffer (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
YY_BUFFER_STATE _mesa_program__create_buffer (FILE *file,int size ,yyscan_t yyscanner );
void _mesa_program__delete_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void _mesa_program__flush_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void _mesa_program_push_buffer_state (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
void _mesa_program_pop_buffer_state (yyscan_t yyscanner );

static void _mesa_program_ensure_buffer_stack (yyscan_t yyscanner );
static void _mesa_program__load_buffer_state (yyscan_t yyscanner );
static void _mesa_program__init_buffer (YY_BUFFER_STATE b,FILE *file ,yyscan_t yyscanner );

#define YY_FLUSH_BUFFER _mesa_program__flush_buffer(YY_CURRENT_BUFFER ,yyscanner)

YY_BUFFER_STATE _mesa_program__scan_buffer (char *base,yy_size_t size ,yyscan_t yyscanner );
YY_BUFFER_STATE _mesa_program__scan_string (yyconst char *yy_str ,yyscan_t yyscanner );
YY_BUFFER_STATE _mesa_program__scan_bytes (yyconst char *bytes,yy_size_t len ,yyscan_t yyscanner );

void *_mesa_program_alloc (yy_size_t ,yyscan_t yyscanner );
void *_mesa_program_realloc (void *,yy_size_t ,yyscan_t yyscanner );
void _mesa_program_free (void * ,yyscan_t yyscanner );

#define yy_new_buffer _mesa_program__create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        _mesa_program_ensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            _mesa_program__create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        _mesa_program_ensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            _mesa_program__create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define _mesa_program_wrap(yyscanner) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state (yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  ,yyscan_t yyscanner);
static int yy_get_next_buffer (yyscan_t yyscanner );
static void yy_fatal_error (yyconst char msg[] ,yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;

#define YY_NUM_RULES 170
#define YY_END_OF_BUFFER 171
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[850] =
    {   0,
        0,    0,  171,  169,  167,  166,  169,  169,  139,  165,
      141,  141,  141,  141,  139,  139,  139,  139,  139,  139,
      139,  139,  139,  139,  139,  139,  139,  139,  139,  139,
      139,  139,  139,  139,  139,  167,    0,    0,  168,  139,
        0,  140,  142,  162,  162,    0,    0,    0,    0,  162,
        0,    0,    0,    0,    0,    0,    0,  119,  163,  120,
      121,  153,  153,  153,  153,    0,  141,    0,  127,  128,
      129,  139,  139,  139,  139,  139,  139,  139,  139,  139,
      139,  139,  139,  139,  139,  139,  139,  139,  139,  139,
      139,  139,  139,  139,  139,  139,  139,  139,  139,  139,

      139,  139,  139,  139,  139,  139,  139,  139,  139,  139,
      139,  139,  139,  139,  139,  139,  139,  139,  139,  139,
      139,  139,  139,  139,  139,  139,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  161,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  160,  160,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      159,  159,  159,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  150,  150,  150,  151,  151,  152,  143,
      142,  143,    0,  144,   11,   12,  139,   13,  139,  139,
       14,   15,  139,   16,   17,   18,   19,   20,   21,    6,

       22,   23,   24,   25,   26,   28,   27,   29,   30,   31,
       32,   33,   34,   35,  139,  139,  139,  139,  139,   40,
       41,  139,   42,   43,   44,   45,   46,   47,   48,  139,
       49,   50,   51,   52,   53,   54,   55,  139,   56,   57,
       58,   59,  139,  139,   64,   65,  139,  139,  139,  139,
      139,  139,    0,    0,    0,    0,  142,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   80,   81,   83,
        0,  158,    0,    0,    0,    0,    0,    0,   97,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  157,
      156,  156,  109,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,  147,  147,  148,  149,    0,  145,   11,
       11,  139,   12,   12,   12,  139,  139,  139,  139,  139,
       15,   15,  139,  130,   16,   16,  139,   17,   17,  139,
       18,   18,  139,   19,   19,  139,   20,   20,  139,   21,
       21,  139,   22,   22,  139,   24,   24,  139,   25,   25,
      139,   28,   28,  139,   27,   27,  139,   30,   30,  139,
       31,   31,  139,   32,   32,  139,   33,   33,  139,   34,
       34,  139,   35,   35,  139,  139,  139,  139,   36,  139,
       38,  139,   40,   40,  139,   41,   41,  139,  131,   42,
       42,  139,   43,   43,  139,  139,   45,   45,  139,   46,

       46,  139,   47,   47,  139,   48,   48,  139,  139,   49,
       49,  139,   50,   50,  139,   51,   51,  139,   52,   52,
      139,   53,   53,  139,   54,   54,  139,  139,   10,   56,
      139,   57,  139,   58,  139,   59,  139,   60,  139,   62,
      139,   64,   64,  139,  139,  139,  139,  139,  139,  139,
      139,    0,  164,    0,    0,    0,   73,   74,    0,    0,
        0,    0,    0,    0,    0,   85,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  155,    0,    0,    0,  113,    0,
      115,    0,    0,    0,    0,    0,    0,  154,  146,  139,

      139,  139,    4,  139,  139,  139,  139,  139,  139,  139,
      139,  139,  139,  139,  139,  139,  139,  139,  139,  139,
      139,  139,  139,  139,  139,  139,    9,   37,   39,  139,
      139,  139,  139,  139,  139,  139,  139,  139,  139,  139,
      139,  139,  139,  139,  139,  139,  139,  139,  139,  139,
       60,  139,   61,   62,  139,   63,  139,  139,  139,  139,
      139,   69,  139,  139,    0,    0,    0,    0,    0,   75,
       76,    0,    0,    0,    0,   84,    0,    0,   88,   91,
        0,    0,    0,    0,    0,    0,    0,  102,  103,    0,
        0,    0,    0,  108,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,  139,  139,  139,  139,  139,  139,
        5,  139,  139,  139,  139,  139,  139,  139,  139,  139,
      139,  139,  139,  139,  139,  139,  139,  139,  139,  139,
        7,    8,  139,  139,  139,  139,  139,  139,  139,  139,
      139,  139,  139,  139,  139,  139,  139,  139,  139,  139,
      139,  139,  139,  139,   61,  139,  139,   63,  139,  139,
      139,  139,  139,   70,  139,   66,    0,    0,    0,    0,
      124,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       94,    0,   98,   99,    0,  101,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  117,  118,    0,    0,

      125,   11,    3,   12,  135,  136,  139,   14,   15,   16,
       17,   18,   19,   20,   21,   22,   24,   25,   28,   27,
       30,   31,   32,   33,   34,   35,   40,   41,   42,   43,
       44,   45,   46,   47,   48,  139,  139,  139,   49,   50,
       51,   52,   53,   54,   55,   56,   57,   58,   59,  139,
      139,  139,  139,   64,   65,  139,   68,  126,    0,    0,
       71,    0,   77,    0,    0,    0,   86,    0,    0,    0,
        0,    0,    0,  100,    0,    0,  106,   93,    0,    0,
        0,    0,    0,    0,  122,    0,  139,  132,  133,  139,
       60,  139,   62,  139,   67,    0,    0,    0,    0,   79,

       82,   87,    0,    0,   92,    0,    0,    0,  105,    0,
        0,    0,    0,  114,  116,    0,  139,  139,   61,   63,
        2,    1,    0,   78,    0,   90,    0,   96,  104,    0,
        0,  111,  112,  123,  139,  134,    0,   89,    0,  107,
      110,  139,   72,   95,  139,  139,  137,  138,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    1,    6,    7,    1,    1,    1,    1,
        1,    1,    8,    1,    8,    9,    1,   10,   11,   12,
       13,   14,   15,   15,   15,   15,   15,    1,    1,    1,
        1,    1,    1,    1,   16,   17,   18,   19,   20,   21,
       22,   23,   24,    7,   25,   26,   27,   28,   29,   30,
       31,   32,   33,   34,   35,   36,   37,   38,   39,   40,
        1,    1,    1,    1,   41,    1,   42,   43,   44,   45,

       46,   47,   48,   49,   50,   51,   52,   53,   54,   55,
       56,   57,   58,   59,   60,   61,   62,   63,   64,   65,
       66,   67,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[68] =
    {   0,
        1,    1,    1,    1,    1,    1,    2,    1,    3,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2
    } ;

static yyconst flex_int16_t yy_base[853] =
    {   0,
        0,    0, 1299, 1300,   66, 1300, 1293, 1294,    0,   69,
       85,  128,  140,  152,  151,   58,   56,   63,   76, 1272,
      158,  160,   39,  163,  173,  189,   52, 1265,   76, 1235,
     1234, 1246, 1230, 1244, 1243,  105, 1272, 1284, 1300,    0,
      225, 1300,  218,  160,  157,   20,  123,   66,  119,  192,
     1244, 1230,   54,  162, 1228, 1240,  194, 1300,  200,  195,
       98,  227,  196,  231,  235,  293,  305,  316, 1300, 1300,
     1300, 1249, 1262, 1256,  223, 1245, 1248, 1244, 1259,  107,
      298, 1241, 1255,  246, 1241, 1254, 1245, 1258, 1235, 1246,
     1237,  182, 1238, 1229, 1238, 1229, 1228, 1229,  144, 1223,

     1229, 1240, 1231, 1225, 1222, 1223, 1227,  289, 1236, 1223,
      302, 1230, 1217, 1231, 1207,   65,  315,  276, 1227, 1226,
     1202, 1187, 1182, 1199, 1175, 1180, 1206,  279, 1195,  293,
     1190,  342,  299, 1192, 1173,  317, 1183, 1179, 1174,  207,
     1180, 1166, 1182, 1179, 1170,  320,  324, 1172, 1161, 1175,
     1178, 1160, 1175, 1162, 1159, 1166,  284, 1174,  227,  288,
      327,  342,  345, 1151, 1168, 1169, 1162, 1144,  318, 1145,
     1167, 1158,  330,  341,  345,  349,  353,  357,  361, 1300,
      419,  430,  436,  442,  440,  441, 1191,    0, 1190, 1173,
     1163,  443, 1183,  444,  451,  468,  470,  472,  471,    0,

      496,    0,  497,  498,    0,  499,  500,    0,  524,  525,
      526,  536,  537,  553, 1178, 1171, 1184,  354,  356,  561,
      563, 1165,  564,  565, 1157,  580,  590,  591,  592, 1178,
      593,  617,  618,  619,  629,  630, 1155, 1165,  330,  362,
      419,  483,  445,  364,  646, 1153, 1145, 1144, 1129, 1129,
     1128, 1127, 1170, 1142, 1130,  662,  669,  643, 1134,  487,
     1131, 1125, 1125, 1119, 1132, 1132, 1117, 1300, 1300, 1132,
     1120,  646, 1127,  135, 1124, 1130,  561, 1125, 1300, 1116,
     1123, 1122, 1125, 1111, 1110, 1114, 1109,  448, 1114,  650,
      653,  665, 1300, 1106, 1104, 1104, 1112, 1113, 1095,  670,

     1100, 1106,  486,  579,  655,  661,  668,  726,  732, 1112,
      682, 1119, 1110,  688,  730, 1117, 1116, 1109, 1123, 1113,
     1104,  712, 1111,    0, 1102,  731, 1109, 1100,  733, 1107,
     1098,  734, 1105, 1096,  736, 1103, 1094,  737, 1101, 1092,
      738, 1099, 1090,  739, 1097, 1088,  740, 1095, 1086,  741,
     1093, 1084,  742, 1091, 1082,  743, 1089, 1080,  744, 1087,
     1078,  745, 1085, 1076,  746, 1083, 1074,  747, 1081, 1072,
      748, 1079, 1070,  749, 1077, 1080, 1073, 1080,    0, 1073,
        0, 1088, 1063,  750, 1070, 1061,  751, 1068,    0, 1059,
      752, 1066, 1057,  755, 1064, 1063, 1054,  758, 1061, 1052,

      776, 1059, 1050,  777, 1057, 1048,  779, 1055, 1058, 1045,
      780, 1052, 1043,  782, 1050, 1041,  783, 1048, 1039,  784,
     1046, 1037,  785, 1044, 1035,  786, 1042, 1041,    0, 1032,
     1039, 1030, 1037, 1028, 1035, 1026, 1033,  787, 1032,  788,
     1047, 1022,  789, 1029, 1028, 1006, 1000, 1005, 1011,  994,
     1009,  424, 1300, 1008,  998, 1002, 1300, 1300,  992, 1001,
      987, 1004,  987,  990,  984, 1300,  985,  984,  981,  988,
      981,  989,  985,  995,  992,  974,  980,  987,  971,  970,
      988,  970,  982,  981, 1300,  980,  970,  974, 1300,  961,
     1300,  966,  966,  974,  957,  958,  968, 1300, 1300, 1000,

      982,  998,    0,  798,  996,  996,  995,  994,  993,  992,
      991,  990,  989,  988,  987,  986,  985,  984,  983,  982,
      981,  980,  979,  978,  965,  958,    0,    0,    0,  975,
      974,  973,  972,  971,  970,  969,  968,  967,  945,  965,
      964,  963,  962,  961,  960,  959,  958,  957,  956,  955,
      929,  936,  793,  927,  934,  794,  950,  949,  918,  921,
      901,    0,  902,  895,  902,  901,  902,  894,  912, 1300,
     1300,  894,  892,  902,  895, 1300,  890,  907,  516, 1300,
      898,  882,  883,  892,  883,  882,  882, 1300,  881,  890,
      880,  896,  893, 1300,  892,  890,  879,  880,  876,  868,

      875,  870,  871,  866,  892,  892,  890,  904,  903,  898,
        0,  886,  885,  884,  883,  882,  881,  880,  879,  878,
      877,  876,  875,  874,  873,  872,  871,  870,  869,  868,
        0,    0,  867,  866,  865,  864,  863,  862,  861,  860,
      859,  804,  858,  857,  856,  855,  854,  853,  852,  851,
      850,  849,  848,  865,  839,  846,  862,  836,  843,  841,
      840,  818,  818,    0,  825,    0,  859,  858,  807,  825,
     1300,  820,  815,  808,  804,  816,  806,  804,  800,  816,
      807,  806, 1300, 1300,  809, 1300,  804,  797,  786,  797,
      789,  793,  806,  801,  804,  786, 1300, 1300,  798,  787,

     1300,    0,    0,    0,    0,    0,  826,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  814,  813,  802,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  785,
      798,  779,  792,    0,    0,  656,    0,    0,  706,  702,
     1300,  649, 1300,  648,  648,  654, 1300,  637,  645,  610,
      612,  608,  608, 1300,  572,  583, 1300, 1300,  577,  573,
      560,  557,  542,  555, 1300,  539,  573,    0,    0,  572,
        0,  555,    0,  546,    0,  562,  551,  495,  479, 1300,

     1300, 1300,  481,  481, 1300,  480,  443,   31, 1300,  141,
      166,  171,  186, 1300, 1300,  211,  236,  276,    0,    0,
     1300, 1300,  290, 1300,  325, 1300,  346, 1300, 1300,  343,
      341, 1300, 1300, 1300,  365,    0,  380, 1300,  371, 1300,
     1300,  486, 1300, 1300,  451,  458,    0,    0, 1300,  836,
      503,  839
    } ;

static yyconst flex_int16_t yy_def[853] =
    {   0,
      849,    1,  849,  849,  849,  849,  849,  850,  851,  849,
      849,  849,  849,  849,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  849,  849,  850,  849,  851,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  852,  849,  849,  849,  849,
      849,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,

      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,

      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,

      849,  849,  849,  849,  849,  849,  849,  849,  849,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,

      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  851,

      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,

      849,  849,  849,  849,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,

      849,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  851,  851,  851,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  849,  849,  849,  849,  849,

      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  851,  851,  851,  851,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  851,  851,  849,  849,  849,  849,
      849,  851,  849,  849,  851,  851,  851,  851,    0,  849,
      849,  849
    } ;

static yyconst flex_int16_t yy_nxt[1368] =
    {   0,
        4,    5,    6,    5,    7,    8,    9,    4,   10,   11,
       12,   13,   14,   11,   11,   15,    9,   16,   17,   18,
       19,    9,    9,    9,   20,   21,   22,    9,   23,   24,
        9,   25,   26,   27,   28,    9,    9,   29,    9,    9,
        9,    9,    9,    9,    9,    9,   30,    9,    9,    9,
        9,    9,    9,    9,    9,    9,   31,    9,   32,   33,
       34,    9,   35,    9,    9,    9,    9,   36,   96,   36,
       41,  116,  137,   97,   80,  138,  829,   42,   43,   43,
       43,   43,   43,   43,   77,   81,   78,  119,   82,  117,
       83,  238,   79,   66,   67,   67,   67,   67,   67,   67,

       84,   85,  239,  150,   68,  120,   36,   86,   36,  151,
       44,   45,   46,   47,   48,   49,   50,   51,   52,  141,
      142,   53,   54,   55,   56,   57,   58,   59,   60,   61,
       68,  143,   62,   63,   64,   65,   66,   67,   67,   67,
       67,   67,   67,  170,  194,  195,   69,   68,   66,   67,
       67,   67,   67,   67,   67,  218,  171,  219,   70,   68,
       66,   67,   67,   67,   67,   67,   67,   72,  139,   73,
       71,   68,  140,   68,  144,   92,   74,  145,   98,   88,
      467,   89,   75,   93,   76,   68,   90,   99,   94,   91,
      101,  100,  102,  103,   95,  468,  830,   68,  136,  133,

      210,  133,  133,  152,  133,  104,  105,  133,  106,  107,
      108,  109,  110,  134,  111,  133,  112,  153,  133,  211,
      135,  831,  113,  114,  154,  115,   41,   43,   43,   43,
       43,   43,   43,  146,  147,  157,  832,  132,  165,  133,
      166,  161,  162,  167,  168,  833,  158,  163,  188,  159,
      133,  169,  160,  265,  189,  164,  834,  201,  133,  174,
      173,  175,  176,  132,  835,  266,  128,  129,   46,   47,
       48,   49,  172,   51,   52,  202,  285,   53,   54,   55,
       56,   57,   58,  130,   60,   61,  286,  243,  131,  244,
      173,  173,  173,  173,  177,  173,  173,  178,  179,  173,

      173,  173,  181,  181,  181,  181,  181,  181,  228,  836,
      196,  197,  182,   66,   67,   67,   67,   67,   67,   67,
      198,  232,  229,  183,   68,  184,  184,  184,  184,  184,
      184,  240,  134,  241,  255,  233,  282,  287,  182,  135,
      258,  258,  283,  288,  242,  837,  258,  430,  164,  256,
       68,  257,  257,  257,  257,  257,  257,  258,  258,  258,
      261,  258,  258,  298,  258,  272,  258,  258,  258,  258,
      431,  258,  381,  299,  258,  258,  379,  838,  258,  432,
      440,  289,  258,  290,  258,  258,  291,  292,  380,  258,
      382,  839,  258,  303,  303,  303,  303,  840,  441,  841,

      258,  842,  433,  258,  303,  303,  303,  303,  304,  303,
      303,  305,  306,  303,  303,  303,  303,  303,  303,  303,
      307,  303,  303,  303,  303,  303,  303,  303,   43,   43,
       43,   43,   43,   43,  843,  844,  434,  308,  132,  309,
      309,  309,  309,  309,  309,  184,  184,  184,  184,  184,
      184,  184,  184,  184,  184,  184,  184,  310,  313,  435,
      321,  325,  311,  314,  132,  322,  326,  438,  328,  847,
      565,  311,  315,  329,  322,  326,  848,  311,  314,  439,
      312,  316,  329,  323,  327,  331,  566,  334,  340,  337,
      332,  330,  335,  341,  338,  482,  845,  846,  483,  332,

      436,  335,  341,  338,   40,  332,  828,  335,  333,  338,
      336,  342,  339,  343,  346,  349,  352,  355,  344,  347,
      350,  353,  356,  437,  827,  826,  825,  344,  347,  350,
      353,  356,  455,  824,  347,  350,  345,  348,  351,  354,
      357,  358,  361,  364,  823,  456,  359,  362,  365,  498,
      498,  498,  498,  367,  370,  359,  362,  365,  368,  371,
      822,  359,  362,  365,  360,  363,  366,  368,  371,  678,
      373,  821,  679,  368,  371,  374,  369,  372,  383,  820,
      386,  390,  393,  384,  374,  387,  391,  394,  819,  818,
      374,  817,  384,  375,  387,  391,  394,  397,  816,  815,

      814,  385,  398,  388,  392,  395,  471,  400,  403,  406,
      410,  398,  401,  404,  407,  411,  813,  398,  812,  472,
      399,  401,  404,  407,  411,  811,  810,  401,  404,  407,
      402,  405,  408,  412,  413,  416,  419,  809,  808,  414,
      417,  420,  498,  498,  498,  498,  422,  425,  414,  417,
      420,  423,  426,  807,  414,  417,  420,  415,  418,  421,
      423,  426,  806,  442,  805,  804,  423,  426,  443,  424,
      427,  257,  257,  257,  257,  257,  257,  443,  257,  257,
      257,  257,  257,  257,  453,  453,  444,  453,  453,  803,
      453,  453,  453,  453,  453,  453,  802,  453,  801,  310,

      453,  453,  800,  799,  453,  313,  485,  453,  453,  798,
      797,  453,  453,  492,  796,  493,  795,  494,  499,  498,
      498,  498,  312,  453,  498,  498,  498,  498,  316,  321,
      495,  498,  498,  498,  498,  309,  309,  309,  309,  309,
      309,  309,  309,  309,  309,  309,  309,  313,  325,  501,
      328,  331,  323,  334,  337,  340,  343,  346,  349,  352,
      355,  358,  361,  364,  367,  370,  373,  383,  386,  390,
      316,  327,  393,  330,  333,  397,  336,  339,  342,  345,
      348,  351,  354,  357,  360,  363,  366,  369,  372,  375,
      385,  388,  392,  400,  403,  395,  406,  410,  399,  413,

      416,  419,  422,  425,  551,  554,  442,  794,  608,  609,
      655,  658,  793,  792,  736,  737,  402,  405,  791,  408,
      412,  790,  415,  418,  421,  424,  427,  552,  555,  444,
      610,  789,  788,  656,  659,  738,   38,   38,   38,  180,
      180,  787,  786,  785,  784,  783,  782,  781,  780,  779,
      778,  777,  776,  775,  774,  773,  772,  771,  770,  769,
      768,  767,  766,  765,  764,  763,  762,  761,  760,  759,
      758,  757,  756,  755,  754,  753,  659,  752,  751,  656,
      750,  749,  748,  747,  746,  745,  744,  743,  742,  741,
      740,  739,  735,  734,  733,  732,  731,  730,  729,  728,

      727,  726,  725,  724,  723,  722,  721,  720,  719,  718,
      717,  716,  715,  714,  713,  712,  711,  710,  709,  708,
      707,  706,  705,  704,  703,  702,  701,  700,  699,  698,
      697,  696,  695,  694,  693,  692,  691,  690,  689,  688,
      687,  686,  685,  684,  683,  682,  681,  680,  677,  676,
      675,  674,  673,  672,  671,  670,  669,  668,  667,  666,
      665,  664,  663,  662,  661,  660,  657,  555,  654,  552,
      653,  652,  651,  650,  649,  648,  647,  646,  645,  644,
      643,  642,  641,  640,  639,  638,  637,  636,  635,  634,
      633,  632,  631,  630,  629,  628,  627,  626,  625,  624,

      623,  622,  621,  620,  619,  618,  617,  616,  615,  614,
      613,  612,  611,  607,  606,  605,  604,  603,  602,  601,
      600,  599,  598,  597,  596,  595,  594,  593,  592,  591,
      590,  589,  588,  587,  586,  585,  584,  583,  582,  581,
      580,  579,  578,  577,  576,  575,  574,  573,  572,  571,
      570,  569,  568,  567,  564,  563,  562,  561,  560,  559,
      558,  557,  444,  556,  553,  550,  437,  549,  435,  548,
      433,  547,  431,  546,  545,  427,  544,  424,  543,  421,
      542,  418,  541,  415,  540,  412,  539,  538,  408,  537,
      405,  536,  402,  535,  399,  534,  533,  395,  532,  392,

      531,  388,  530,  385,  529,  528,  527,  526,  525,  524,
      375,  523,  372,  522,  369,  521,  366,  520,  363,  519,
      360,  518,  357,  517,  354,  516,  351,  515,  348,  514,
      345,  513,  342,  512,  339,  511,  336,  510,  333,  509,
      330,  508,  327,  507,  323,  506,  505,  504,  503,  502,
      316,  500,  312,  497,  496,  491,  490,  489,  488,  487,
      486,  484,  481,  480,  479,  478,  477,  476,  475,  474,
      473,  470,  469,  466,  465,  464,  463,  462,  461,  460,
      459,  458,  457,  454,  289,  261,  452,  451,  450,  449,
      448,  447,  446,  445,  429,  428,  409,  396,  389,  378,

      377,  376,  324,  320,  319,  318,  317,  302,  301,  300,
      297,  296,  295,  294,  293,  284,  281,  280,  279,  278,
      277,  276,  275,  274,  273,  271,  270,  269,  268,  267,
      264,  263,  262,  260,  259,  172,  254,  253,  252,  251,
      250,  249,  248,  247,  246,  245,  237,  236,  235,  234,
      231,  230,  227,  226,  225,  224,  223,  222,  221,  220,
      217,  216,  215,  214,  213,  212,  209,  208,  207,  206,
      205,  204,  203,  200,  199,  193,  192,  191,  190,  187,
      186,  185,  156,  155,  149,  148,   39,  127,  126,  125,
      124,  123,  122,  121,  118,   87,   39,   37,  849,    3,

      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849
    } ;

static yyconst flex_int16_t yy_chk[1368] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    5,   23,    5,
       10,   27,   46,   23,   17,   46,  808,   10,   10,   10,
       10,   10,   10,   10,   16,   17,   16,   29,   17,   27,
       18,  116,   16,   11,   11,   11,   11,   11,   11,   11,

       18,   19,  116,   53,   11,   29,   36,   19,   36,   53,
       10,   10,   10,   10,   10,   10,   10,   10,   10,   48,
       48,   10,   10,   10,   10,   10,   10,   10,   10,   10,
       11,   48,   10,   10,   10,   10,   12,   12,   12,   12,
       12,   12,   12,   61,   80,   80,   12,   12,   13,   13,
       13,   13,   13,   13,   13,   99,   61,   99,   13,   13,
       14,   14,   14,   14,   14,   14,   14,   15,   47,   15,
       14,   14,   47,   12,   49,   22,   15,   49,   24,   21,
      274,   21,   15,   22,   15,   13,   21,   24,   22,   21,
       25,   24,   25,   25,   22,  274,  810,   14,   45,   45,

       92,   44,   44,   54,   45,   25,   26,   44,   26,   26,
       26,   26,   26,   44,   26,   45,   26,   54,   44,   92,
       44,  811,   26,   26,   54,   26,   41,   43,   43,   43,
       43,   43,   43,   50,   50,   57,  812,   43,   60,   50,
       60,   59,   59,   60,   60,  813,   57,   59,   75,   57,
       50,   60,   57,  140,   75,   59,  816,   84,   59,   63,
       63,   63,   63,   43,  817,  140,   41,   41,   41,   41,
       41,   41,   62,   41,   41,   84,  159,   41,   41,   41,
       41,   41,   41,   41,   41,   41,  159,  118,   41,  118,
       62,   62,   62,   62,   64,   64,   64,   64,   65,   65,

       65,   65,   66,   66,   66,   66,   66,   66,  108,  818,
       81,   81,   66,   67,   67,   67,   67,   67,   67,   67,
       81,  111,  108,   68,   67,   68,   68,   68,   68,   68,
       68,  117,  128,  117,  130,  111,  157,  160,   66,  128,
      133,  133,  157,  160,  117,  823,  133,  239,  130,  132,
       67,  132,  132,  132,  132,  132,  132,  133,  136,  136,
      136,  146,  146,  169,  136,  147,  147,  146,  161,  161,
      239,  147,  219,  169,  161,  136,  218,  825,  146,  240,
      244,  161,  147,  162,  162,  161,  163,  163,  218,  162,
      219,  827,  163,  173,  173,  173,  173,  830,  244,  831,

      162,  835,  240,  163,  174,  174,  174,  174,  175,  175,
      175,  175,  176,  176,  176,  176,  177,  177,  177,  177,
      178,  178,  178,  178,  179,  179,  179,  179,  181,  181,
      181,  181,  181,  181,  837,  839,  241,  182,  181,  182,
      182,  182,  182,  182,  182,  183,  183,  183,  183,  183,
      183,  184,  184,  184,  184,  184,  184,  185,  186,  241,
      192,  194,  185,  186,  181,  192,  194,  243,  195,  845,
      452,  185,  186,  195,  192,  194,  846,  185,  186,  243,
      185,  186,  195,  192,  194,  196,  452,  197,  199,  198,
      196,  195,  197,  199,  198,  288,  842,  842,  288,  196,

      242,  197,  199,  198,  851,  196,  807,  197,  196,  198,
      197,  199,  198,  201,  203,  204,  206,  207,  201,  203,
      204,  206,  207,  242,  806,  804,  803,  201,  203,  204,
      206,  207,  260,  799,  203,  204,  201,  203,  204,  206,
      207,  209,  210,  211,  798,  260,  209,  210,  211,  303,
      303,  303,  303,  212,  213,  209,  210,  211,  212,  213,
      797,  209,  210,  211,  209,  210,  211,  212,  213,  579,
      214,  796,  579,  212,  213,  214,  212,  213,  220,  794,
      221,  223,  224,  220,  214,  221,  223,  224,  792,  790,
      214,  787,  220,  214,  221,  223,  224,  226,  786,  784,

      783,  220,  226,  221,  223,  224,  277,  227,  228,  229,
      231,  226,  227,  228,  229,  231,  782,  226,  781,  277,
      226,  227,  228,  229,  231,  780,  779,  227,  228,  229,
      227,  228,  229,  231,  232,  233,  234,  776,  775,  232,
      233,  234,  304,  304,  304,  304,  235,  236,  232,  233,
      234,  235,  236,  773,  232,  233,  234,  232,  233,  234,
      235,  236,  772,  245,  771,  770,  235,  236,  245,  235,
      236,  256,  256,  256,  256,  256,  256,  245,  257,  257,
      257,  257,  257,  257,  258,  258,  245,  272,  272,  769,
      258,  290,  290,  272,  291,  291,  768,  290,  766,  311,

      291,  258,  765,  764,  272,  314,  292,  292,  290,  762,
      760,  291,  292,  300,  759,  300,  756,  300,  305,  305,
      305,  305,  311,  292,  306,  306,  306,  306,  314,  322,
      300,  307,  307,  307,  307,  308,  308,  308,  308,  308,
      308,  309,  309,  309,  309,  309,  309,  315,  326,  315,
      329,  332,  322,  335,  338,  341,  344,  347,  350,  353,
      356,  359,  362,  365,  368,  371,  374,  384,  387,  391,
      315,  326,  394,  329,  332,  398,  335,  338,  341,  344,
      347,  350,  353,  356,  359,  362,  365,  368,  371,  374,
      384,  387,  391,  401,  404,  394,  407,  411,  398,  414,

      417,  420,  423,  426,  438,  440,  443,  753,  504,  504,
      553,  556,  752,  751,  642,  642,  401,  404,  750,  407,
      411,  738,  414,  417,  420,  423,  426,  438,  440,  443,
      504,  737,  736,  553,  556,  642,  850,  850,  850,  852,
      852,  707,  700,  699,  696,  695,  694,  693,  692,  691,
      690,  689,  688,  687,  685,  682,  681,  680,  679,  678,
      677,  676,  675,  674,  673,  672,  670,  669,  668,  667,
      665,  663,  662,  661,  660,  659,  658,  657,  656,  655,
      654,  653,  652,  651,  650,  649,  648,  647,  646,  645,
      644,  643,  641,  640,  639,  638,  637,  636,  635,  634,

      633,  630,  629,  628,  627,  626,  625,  624,  623,  622,
      621,  620,  619,  618,  617,  616,  615,  614,  613,  612,
      610,  609,  608,  607,  606,  605,  604,  603,  602,  601,
      600,  599,  598,  597,  596,  595,  593,  592,  591,  590,
      589,  587,  586,  585,  584,  583,  582,  581,  578,  577,
      575,  574,  573,  572,  569,  568,  567,  566,  565,  564,
      563,  561,  560,  559,  558,  557,  555,  554,  552,  551,
      550,  549,  548,  547,  546,  545,  544,  543,  542,  541,
      540,  539,  538,  537,  536,  535,  534,  533,  532,  531,
      530,  526,  525,  524,  523,  522,  521,  520,  519,  518,

      517,  516,  515,  514,  513,  512,  511,  510,  509,  508,
      507,  506,  505,  502,  501,  500,  497,  496,  495,  494,
      493,  492,  490,  488,  487,  486,  484,  483,  482,  481,
      480,  479,  478,  477,  476,  475,  474,  473,  472,  471,
      470,  469,  468,  467,  465,  464,  463,  462,  461,  460,
      459,  456,  455,  454,  451,  450,  449,  448,  447,  446,
      445,  444,  442,  441,  439,  437,  436,  435,  434,  433,
      432,  431,  430,  428,  427,  425,  424,  422,  421,  419,
      418,  416,  415,  413,  412,  410,  409,  408,  406,  405,
      403,  402,  400,  399,  397,  396,  395,  393,  392,  390,

      388,  386,  385,  383,  382,  380,  378,  377,  376,  375,
      373,  372,  370,  369,  367,  366,  364,  363,  361,  360,
      358,  357,  355,  354,  352,  351,  349,  348,  346,  345,
      343,  342,  340,  339,  337,  336,  334,  333,  331,  330,
      328,  327,  325,  323,  321,  320,  319,  318,  317,  316,
      313,  312,  310,  302,  301,  299,  298,  297,  296,  295,
      294,  289,  287,  286,  285,  284,  283,  282,  281,  280,
      278,  276,  275,  273,  271,  270,  267,  266,  265,  264,
      263,  262,  261,  259,  255,  254,  253,  252,  251,  250,
      249,  248,  247,  246,  238,  237,  230,  225,  222,  217,

      216,  215,  193,  191,  190,  189,  187,  172,  171,  170,
      168,  167,  166,  165,  164,  158,  156,  155,  154,  153,
      152,  151,  150,  149,  148,  145,  144,  143,  142,  141,
      139,  138,  137,  135,  134,  131,  129,  127,  126,  125,
      124,  123,  122,  121,  120,  119,  115,  114,  113,  112,
      110,  109,  107,  106,  105,  104,  103,  102,  101,  100,
       98,   97,   96,   95,   94,   93,   91,   90,   89,   88,
       87,   86,   85,   83,   82,   79,   78,   77,   76,   74,
       73,   72,   56,   55,   52,   51,   38,   37,   35,   34,
       33,   32,   31,   30,   28,   20,    8,    7,    3,  849,

      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "program_lexer.l"
#line 2 "program_lexer.l"
/*
 * Copyright © 2009 Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
#include "main/glheader.h"
#include "main/imports.h"
#include "program/prog_instruction.h"
#include "program/prog_statevars.h"
#include "program/symbol_table.h"
#include "program/program_parser.h"
#include "program/program_parse.tab.h"

#define require_ARB_vp (yyextra->mode == ARB_vertex)
#define require_ARB_fp (yyextra->mode == ARB_fragment)
#define require_NV_fp  (yyextra->option.NV_fragment)
#define require_shadow (yyextra->option.Shadow)
#define require_rect   (yyextra->option.TexRect)
#define require_texarray        (yyextra->option.TexArray)

#ifndef HAVE_UNISTD_H
#define YY_NO_UNISTD_H
#endif

#define return_token_or_IDENTIFIER(condition, token)	\
   do {							\
      if (condition) {					\
	 return token;					\
      } else {						\
	 return handle_ident(yyextra, yytext, yylval);	\
      }							\
   } while (0)

#define return_token_or_DOT(condition, token)		\
   do {							\
      if (condition) {					\
	 return token;					\
      } else {						\
	 yyless(1);					\
	 return DOT;					\
      }							\
   } while (0)


#define return_opcode(condition, token, opcode, len)	\
   do {							\
      if (condition &&					\
	  _mesa_parse_instruction_suffix(yyextra,	\
					 yytext + len,	\
					 & yylval->temp_inst)) {	\
	 yylval->temp_inst.Opcode = OPCODE_ ## opcode;	\
	 return token;					\
      } else {						\
	 return handle_ident(yyextra, yytext, yylval);	\
      }							\
   } while (0)

#define SWIZZLE_INVAL  MAKE_SWIZZLE4(SWIZZLE_NIL, SWIZZLE_NIL, \
				     SWIZZLE_NIL, SWIZZLE_NIL)

static unsigned
mask_from_char(char c)
{
   switch (c) {
   case 'x':
   case 'r':
      return WRITEMASK_X;
   case 'y':
   case 'g':
      return WRITEMASK_Y;
   case 'z':
   case 'b':
      return WRITEMASK_Z;
   case 'w':
   case 'a':
      return WRITEMASK_W;
   }

   return 0;
}

static unsigned
swiz_from_char(char c)
{
   switch (c) {
   case 'x':
   case 'r':
      return SWIZZLE_X;
   case 'y':
   case 'g':
      return SWIZZLE_Y;
   case 'z':
   case 'b':
      return SWIZZLE_Z;
   case 'w':
   case 'a':
      return SWIZZLE_W;
   }

   return 0;
}

static int
handle_ident(struct asm_parser_state *state, const char *text, YYSTYPE *lval)
{
   lval->string = strdup(text);

   return (_mesa_symbol_table_find_symbol(state->st, 0, text) == NULL)
      ? IDENTIFIER : USED_IDENTIFIER;
}

#define YY_USER_ACTION							\
   do {									\
      yylloc->first_column = yylloc->last_column;			\
      yylloc->last_column += yyleng;					\
      if ((yylloc->first_line == 1)					\
	  && (yylloc->first_column == 1)) {				\
	 yylloc->position = 1;						\
      } else {								\
	 yylloc->position += yylloc->last_column - yylloc->first_column; \
      }									\
   } while(0);

#define YY_NO_INPUT

/* Yes, this is intentionally doing nothing. We have this line of code
here only to avoid the compiler complaining about an unput function
that is defined, but never called. */
#define YY_USER_INIT while (0) { unput(0); }

#define YY_EXTRA_TYPE struct asm_parser_state *

/* Flex defines a couple of functions with no declarations nor the
static keyword. Declare them here to avoid a compiler warning. */
int _mesa_program_get_column  (yyscan_t yyscanner);
void _mesa_program_set_column (int  column_no , yyscan_t yyscanner);

#line 1170 "lex.yy.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    yy_size_t yy_n_chars;
    yy_size_t yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    YYLTYPE * yylloc_r;

    }; /* end struct yyguts_t */

static int yy_init_globals (yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
    #    define yylloc yyg->yylloc_r
    
int _mesa_program_lex_init (yyscan_t* scanner);

int _mesa_program_lex_init_extra (YY_EXTRA_TYPE user_defined,yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int _mesa_program_lex_destroy (yyscan_t yyscanner );

int _mesa_program_get_debug (yyscan_t yyscanner );

void _mesa_program_set_debug (int debug_flag ,yyscan_t yyscanner );

YY_EXTRA_TYPE _mesa_program_get_extra (yyscan_t yyscanner );

void _mesa_program_set_extra (YY_EXTRA_TYPE user_defined ,yyscan_t yyscanner );

FILE *_mesa_program_get_in (yyscan_t yyscanner );

void _mesa_program_set_in  (FILE * in_str ,yyscan_t yyscanner );

FILE *_mesa_program_get_out (yyscan_t yyscanner );

void _mesa_program_set_out  (FILE * out_str ,yyscan_t yyscanner );

yy_size_t _mesa_program_get_leng (yyscan_t yyscanner );

char *_mesa_program_get_text (yyscan_t yyscanner );

int _mesa_program_get_lineno (yyscan_t yyscanner );

void _mesa_program_set_lineno (int line_number ,yyscan_t yyscanner );

int _mesa_program_get_column  (yyscan_t yyscanner );

void _mesa_program_set_column (int column_no ,yyscan_t yyscanner );

YYSTYPE * _mesa_program_get_lval (yyscan_t yyscanner );

void _mesa_program_set_lval (YYSTYPE * yylval_param ,yyscan_t yyscanner );

       YYLTYPE *_mesa_program_get_lloc (yyscan_t yyscanner );
    
        void _mesa_program_set_lloc (YYLTYPE * yylloc_param ,yyscan_t yyscanner );
    
/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int _mesa_program_wrap (yyscan_t yyscanner );
#else
extern int _mesa_program_wrap (yyscan_t yyscanner );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  ,yyscan_t yyscanner);
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int ,yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * ,yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (yyscan_t yyscanner );
#else
static int input (yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int _mesa_program_lex \
               (YYSTYPE * yylval_param,YYLTYPE * yylloc_param ,yyscan_t yyscanner);

#define YY_DECL int _mesa_program_lex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

#line 170 "program_lexer.l"


#line 1418 "lex.yy.c"

    yylval = yylval_param;

    yylloc = yylloc_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			_mesa_program_ensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				_mesa_program__create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
		}

		_mesa_program__load_buffer_state(yyscanner );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 850 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1300 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 172 "program_lexer.l"
{ return ARBvp_10; }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 173 "program_lexer.l"
{ return ARBfp_10; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 174 "program_lexer.l"
{
   yylval->integer = at_address;
   return_token_or_IDENTIFIER(require_ARB_vp, ADDRESS);
}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 178 "program_lexer.l"
{ return ALIAS; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 179 "program_lexer.l"
{ return ATTRIB; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 180 "program_lexer.l"
{ return END; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 181 "program_lexer.l"
{ return OPTION; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 182 "program_lexer.l"
{ return OUTPUT; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 183 "program_lexer.l"
{ return PARAM; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 184 "program_lexer.l"
{ yylval->integer = at_temp; return TEMP; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 186 "program_lexer.l"
{ return_opcode(             1, VECTOR_OP, ABS, 3); }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 187 "program_lexer.l"
{ return_opcode(             1, BIN_OP, ADD, 3); }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 188 "program_lexer.l"
{ return_opcode(require_ARB_vp, ARL, ARL, 3); }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 190 "program_lexer.l"
{ return_opcode(require_ARB_fp, TRI_OP, CMP, 3); }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 191 "program_lexer.l"
{ return_opcode(require_ARB_fp, SCALAR_OP, COS, 3); }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 193 "program_lexer.l"
{ return_opcode(require_NV_fp,  VECTOR_OP, DDX, 3); }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 194 "program_lexer.l"
{ return_opcode(require_NV_fp,  VECTOR_OP, DDY, 3); }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 195 "program_lexer.l"
{ return_opcode(             1, BIN_OP, DP3, 3); }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 196 "program_lexer.l"
{ return_opcode(             1, BIN_OP, DP4, 3); }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 197 "program_lexer.l"
{ return_opcode(             1, BIN_OP, DPH, 3); }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 198 "program_lexer.l"
{ return_opcode(             1, BIN_OP, DST, 3); }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 200 "program_lexer.l"
{ return_opcode(             1, SCALAR_OP, EX2, 3); }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 201 "program_lexer.l"
{ return_opcode(require_ARB_vp, SCALAR_OP, EXP, 3); }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 203 "program_lexer.l"
{ return_opcode(             1, VECTOR_OP, FLR, 3); }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 204 "program_lexer.l"
{ return_opcode(             1, VECTOR_OP, FRC, 3); }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 206 "program_lexer.l"
{ return_opcode(require_ARB_fp, KIL, KIL, 3); }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 208 "program_lexer.l"
{ return_opcode(             1, VECTOR_OP, LIT, 3); }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 209 "program_lexer.l"
{ return_opcode(             1, SCALAR_OP, LG2, 3); }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 210 "program_lexer.l"
{ return_opcode(require_ARB_vp, SCALAR_OP, LOG, 3); }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 211 "program_lexer.l"
{ return_opcode(require_ARB_fp, TRI_OP, LRP, 3); }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 213 "program_lexer.l"
{ return_opcode(             1, TRI_OP, MAD, 3); }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 214 "program_lexer.l"
{ return_opcode(             1, BIN_OP, MAX, 3); }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 215 "program_lexer.l"
{ return_opcode(             1, BIN_OP, MIN, 3); }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 216 "program_lexer.l"
{ return_opcode(             1, VECTOR_OP, MOV, 3); }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 217 "program_lexer.l"
{ return_opcode(             1, BIN_OP, MUL, 3); }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 219 "program_lexer.l"
{ return_opcode(require_NV_fp,  VECTOR_OP, PK2H, 4); }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 220 "program_lexer.l"
{ return_opcode(require_NV_fp,  VECTOR_OP, PK2US, 5); }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 221 "program_lexer.l"
{ return_opcode(require_NV_fp,  VECTOR_OP, PK4B, 4); }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 222 "program_lexer.l"
{ return_opcode(require_NV_fp,  VECTOR_OP, PK4UB, 5); }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 223 "program_lexer.l"
{ return_opcode(             1, BINSC_OP, POW, 3); }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 225 "program_lexer.l"
{ return_opcode(             1, SCALAR_OP, RCP, 3); }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 226 "program_lexer.l"
{ return_opcode(require_NV_fp,  BIN_OP,    RFL, 3); }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 227 "program_lexer.l"
{ return_opcode(             1, SCALAR_OP, RSQ, 3); }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 229 "program_lexer.l"
{ return_opcode(require_ARB_fp, SCALAR_OP, SCS, 3); }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 230 "program_lexer.l"
{ return_opcode(require_NV_fp,  BIN_OP, SEQ, 3); }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 231 "program_lexer.l"
{ return_opcode(require_NV_fp,  BIN_OP, SFL, 3); }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 232 "program_lexer.l"
{ return_opcode(             1, BIN_OP, SGE, 3); }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 233 "program_lexer.l"
{ return_opcode(require_NV_fp,  BIN_OP, SGT, 3); }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 234 "program_lexer.l"
{ return_opcode(require_ARB_fp, SCALAR_OP, SIN, 3); }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 235 "program_lexer.l"
{ return_opcode(require_NV_fp,  BIN_OP, SLE, 3); }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 236 "program_lexer.l"
{ return_opcode(             1, BIN_OP, SLT, 3); }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 237 "program_lexer.l"
{ return_opcode(require_NV_fp,  BIN_OP, SNE, 3); }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 238 "program_lexer.l"
{ return_opcode(require_NV_fp,  BIN_OP, STR, 3); }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 239 "program_lexer.l"
{ return_opcode(             1, BIN_OP, SUB, 3); }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 240 "program_lexer.l"
{ return_opcode(             1, SWZ, SWZ, 3); }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 242 "program_lexer.l"
{ return_opcode(require_ARB_fp, SAMPLE_OP, TEX, 3); }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 243 "program_lexer.l"
{ return_opcode(require_ARB_fp, SAMPLE_OP, TXB, 3); }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 244 "program_lexer.l"
{ return_opcode(require_NV_fp,  TXD_OP, TXD, 3); }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 245 "program_lexer.l"
{ return_opcode(require_ARB_fp, SAMPLE_OP, TXP, 3); }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 247 "program_lexer.l"
{ return_opcode(require_NV_fp,  SCALAR_OP, UP2H, 4); }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 248 "program_lexer.l"
{ return_opcode(require_NV_fp,  SCALAR_OP, UP2US, 5); }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 249 "program_lexer.l"
{ return_opcode(require_NV_fp,  SCALAR_OP, UP4B, 4); }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 250 "program_lexer.l"
{ return_opcode(require_NV_fp,  SCALAR_OP, UP4UB, 5); }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 252 "program_lexer.l"
{ return_opcode(require_NV_fp,  TRI_OP, X2D, 3); }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 253 "program_lexer.l"
{ return_opcode(             1, BIN_OP, XPD, 3); }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 255 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_vp, VERTEX); }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 256 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp, FRAGMENT); }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 257 "program_lexer.l"
{ return PROGRAM; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 258 "program_lexer.l"
{ return STATE; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 259 "program_lexer.l"
{ return RESULT; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 261 "program_lexer.l"
{ return AMBIENT; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 262 "program_lexer.l"
{ return ATTENUATION; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 263 "program_lexer.l"
{ return BACK; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 264 "program_lexer.l"
{ return_token_or_DOT(require_ARB_vp, CLIP); }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 265 "program_lexer.l"
{ return COLOR; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 266 "program_lexer.l"
{ return_token_or_DOT(require_ARB_fp, DEPTH); }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 267 "program_lexer.l"
{ return DIFFUSE; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 268 "program_lexer.l"
{ return DIRECTION; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 269 "program_lexer.l"
{ return EMISSION; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 270 "program_lexer.l"
{ return ENV; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 271 "program_lexer.l"
{ return EYE; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 272 "program_lexer.l"
{ return FOGCOORD; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 273 "program_lexer.l"
{ return FOG; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 274 "program_lexer.l"
{ return FRONT; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 275 "program_lexer.l"
{ return HALF; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 276 "program_lexer.l"
{ return INVERSE; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 277 "program_lexer.l"
{ return INVTRANS; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 278 "program_lexer.l"
{ return LIGHT; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 279 "program_lexer.l"
{ return LIGHTMODEL; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 280 "program_lexer.l"
{ return LIGHTPROD; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 281 "program_lexer.l"
{ return LOCAL; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 282 "program_lexer.l"
{ return MATERIAL; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 283 "program_lexer.l"
{ return MAT_PROGRAM; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 284 "program_lexer.l"
{ return MATRIX; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 285 "program_lexer.l"
{ return_token_or_DOT(require_ARB_vp, MATRIXINDEX); }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 286 "program_lexer.l"
{ return MODELVIEW; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 287 "program_lexer.l"
{ return MVP; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 288 "program_lexer.l"
{ return_token_or_DOT(require_ARB_vp, NORMAL); }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 289 "program_lexer.l"
{ return OBJECT; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 290 "program_lexer.l"
{ return PALETTE; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 291 "program_lexer.l"
{ return PARAMS; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 292 "program_lexer.l"
{ return PLANE; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 293 "program_lexer.l"
{ return_token_or_DOT(require_ARB_vp, POINT_TOK); }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 294 "program_lexer.l"
{ return_token_or_DOT(require_ARB_vp, POINTSIZE); }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 295 "program_lexer.l"
{ return POSITION; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 296 "program_lexer.l"
{ return PRIMARY; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 297 "program_lexer.l"
{ return PROJECTION; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 298 "program_lexer.l"
{ return_token_or_DOT(require_ARB_fp, RANGE); }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 299 "program_lexer.l"
{ return ROW; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 300 "program_lexer.l"
{ return SCENECOLOR; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 301 "program_lexer.l"
{ return SECONDARY; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 302 "program_lexer.l"
{ return SHININESS; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 303 "program_lexer.l"
{ return_token_or_DOT(require_ARB_vp, SIZE_TOK); }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 304 "program_lexer.l"
{ return SPECULAR; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 305 "program_lexer.l"
{ return SPOT; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 306 "program_lexer.l"
{ return TEXCOORD; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 307 "program_lexer.l"
{ return_token_or_DOT(require_ARB_fp, TEXENV); }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 308 "program_lexer.l"
{ return_token_or_DOT(require_ARB_vp, TEXGEN); }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 309 "program_lexer.l"
{ return_token_or_DOT(require_ARB_vp, TEXGEN_Q); }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 310 "program_lexer.l"
{ return_token_or_DOT(require_ARB_vp, TEXGEN_S); }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 311 "program_lexer.l"
{ return_token_or_DOT(require_ARB_vp, TEXGEN_T); }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 312 "program_lexer.l"
{ return TEXTURE; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 313 "program_lexer.l"
{ return TRANSPOSE; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 314 "program_lexer.l"
{ return_token_or_DOT(require_ARB_vp, VTXATTRIB); }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 315 "program_lexer.l"
{ return_token_or_DOT(require_ARB_vp, WEIGHT); }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 317 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp, TEXTURE_UNIT); }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 318 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp, TEX_1D); }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 319 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp, TEX_2D); }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 320 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp, TEX_3D); }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 321 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp, TEX_CUBE); }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 322 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp && require_rect, TEX_RECT); }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 323 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp && require_shadow, TEX_SHADOW1D); }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 324 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp && require_shadow, TEX_SHADOW2D); }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 325 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp && require_shadow && require_rect, TEX_SHADOWRECT); }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 326 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp && require_texarray, TEX_ARRAY1D); }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 327 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp && require_texarray, TEX_ARRAY2D); }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 328 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp && require_shadow && require_texarray, TEX_ARRAYSHADOW1D); }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 329 "program_lexer.l"
{ return_token_or_IDENTIFIER(require_ARB_fp && require_shadow && require_texarray, TEX_ARRAYSHADOW2D); }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 331 "program_lexer.l"
{ return handle_ident(yyextra, yytext, yylval); }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 333 "program_lexer.l"
{ return DOT_DOT; }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 335 "program_lexer.l"
{
   yylval->integer = strtol(yytext, NULL, 10);
   return INTEGER;
}
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 339 "program_lexer.l"
{
   yylval->real = _mesa_strtof(yytext, NULL);
   return REAL;
}
	YY_BREAK
case 143:
/* rule 143 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 343 "program_lexer.l"
{
   yylval->real = _mesa_strtof(yytext, NULL);
   return REAL;
}
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 347 "program_lexer.l"
{
   yylval->real = _mesa_strtof(yytext, NULL);
   return REAL;
}
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 351 "program_lexer.l"
{
   yylval->real = _mesa_strtof(yytext, NULL);
   return REAL;
}
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 356 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_NOOP;
   yylval->swiz_mask.mask = WRITEMASK_XYZW;
   return MASK4;
}
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 362 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_INVAL;
   yylval->swiz_mask.mask = WRITEMASK_XY
      | mask_from_char(yytext[3]);
   return MASK3;
}
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 368 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_INVAL;
   yylval->swiz_mask.mask = WRITEMASK_XZW;
   return MASK3;
}
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 373 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_INVAL;
   yylval->swiz_mask.mask = WRITEMASK_YZW;
   return MASK3;
}
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 379 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_INVAL;
   yylval->swiz_mask.mask = WRITEMASK_X
      | mask_from_char(yytext[2]);
   return MASK2;
}
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 385 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_INVAL;
   yylval->swiz_mask.mask = WRITEMASK_Y
      | mask_from_char(yytext[2]);
   return MASK2;
}
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 391 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_INVAL;
   yylval->swiz_mask.mask = WRITEMASK_ZW;
   return MASK2;
}
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 397 "program_lexer.l"
{
   const unsigned s = swiz_from_char(yytext[1]);
   yylval->swiz_mask.swizzle = MAKE_SWIZZLE4(s, s, s, s);
   yylval->swiz_mask.mask = mask_from_char(yytext[1]);
   return MASK1; 
}
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 404 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = MAKE_SWIZZLE4(swiz_from_char(yytext[1]),
					    swiz_from_char(yytext[2]),
					    swiz_from_char(yytext[3]),
					    swiz_from_char(yytext[4]));
   yylval->swiz_mask.mask = 0;
   return SWIZZLE;
}
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 413 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_NOOP;
   yylval->swiz_mask.mask = WRITEMASK_XYZW;
   return_token_or_DOT(require_ARB_fp, MASK4);
}
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 419 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_INVAL;
   yylval->swiz_mask.mask = WRITEMASK_XY
      | mask_from_char(yytext[3]);
   return_token_or_DOT(require_ARB_fp, MASK3);
}
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 425 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_INVAL;
   yylval->swiz_mask.mask = WRITEMASK_XZW;
   return_token_or_DOT(require_ARB_fp, MASK3);
}
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 430 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_INVAL;
   yylval->swiz_mask.mask = WRITEMASK_YZW;
   return_token_or_DOT(require_ARB_fp, MASK3);
}
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 436 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_INVAL;
   yylval->swiz_mask.mask = WRITEMASK_X
      | mask_from_char(yytext[2]);
   return_token_or_DOT(require_ARB_fp, MASK2);
}
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 442 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_INVAL;
   yylval->swiz_mask.mask = WRITEMASK_Y
      | mask_from_char(yytext[2]);
   return_token_or_DOT(require_ARB_fp, MASK2);
}
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 448 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = SWIZZLE_INVAL;
   yylval->swiz_mask.mask = WRITEMASK_ZW;
   return_token_or_DOT(require_ARB_fp, MASK2);
}
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 454 "program_lexer.l"
{
   const unsigned s = swiz_from_char(yytext[1]);
   yylval->swiz_mask.swizzle = MAKE_SWIZZLE4(s, s, s, s);
   yylval->swiz_mask.mask = mask_from_char(yytext[1]);
   return_token_or_DOT(require_ARB_fp, MASK1);
}
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 462 "program_lexer.l"
{
   if (require_ARB_vp) {
      return TEXGEN_R;
   } else {
      yylval->swiz_mask.swizzle = MAKE_SWIZZLE4(SWIZZLE_X, SWIZZLE_X,
						SWIZZLE_X, SWIZZLE_X);
      yylval->swiz_mask.mask = WRITEMASK_X;
      return MASK1;
   }
}
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 473 "program_lexer.l"
{
   yylval->swiz_mask.swizzle = MAKE_SWIZZLE4(swiz_from_char(yytext[1]),
					    swiz_from_char(yytext[2]),
					    swiz_from_char(yytext[3]),
					    swiz_from_char(yytext[4]));
   yylval->swiz_mask.mask = 0;
   return_token_or_DOT(require_ARB_fp, SWIZZLE);
}
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 482 "program_lexer.l"
{ return DOT; }
	YY_BREAK
case 166:
/* rule 166 can match eol */
YY_RULE_SETUP
#line 484 "program_lexer.l"
{
   yylloc->first_line++;
   yylloc->first_column = 1;
   yylloc->last_line++;
   yylloc->last_column = 1;
   yylloc->position++;
}
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 491 "program_lexer.l"
/* eat whitespace */ ;
	YY_BREAK
case 168:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 492 "program_lexer.l"
/* eat comments */ ;
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 493 "program_lexer.l"
{ return yytext[0]; }
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 494 "program_lexer.l"
ECHO;
	YY_BREAK
#line 2482 "lex.yy.c"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * _mesa_program_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( _mesa_program_wrap(yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of _mesa_program_lex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = yyg->yytext_ptr;
	register int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					_mesa_program_realloc((void *) b->yy_ch_buf,b->yy_buf_size + 2 ,yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			_mesa_program_restart(yyin  ,yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) (yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) _mesa_program_realloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size ,yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 850 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	register int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	register char *yy_cp = yyg->yy_c_buf_p;

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 850 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 849);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp , yyscan_t yyscanner)
{
	register char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yy_cp = yyg->yy_c_buf_p;

	/* undo effects of setting up yytext */
	*yy_cp = yyg->yy_hold_char;

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = yyg->yy_n_chars + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	yyg->yytext_ptr = yy_bp;
	yyg->yy_hold_char = *yy_cp;
	yyg->yy_c_buf_p = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			yy_size_t offset = yyg->yy_c_buf_p - yyg->yytext_ptr;
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					_mesa_program_restart(yyin ,yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( _mesa_program_wrap(yyscanner ) )
						return EOF;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void _mesa_program_restart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        _mesa_program_ensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            _mesa_program__create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
	}

	_mesa_program__init_buffer(YY_CURRENT_BUFFER,input_file ,yyscanner);
	_mesa_program__load_buffer_state(yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void _mesa_program__switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		_mesa_program_pop_buffer_state();
	 *		_mesa_program_push_buffer_state(new_buffer);
     */
	_mesa_program_ensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	_mesa_program__load_buffer_state(yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (_mesa_program_wrap()) processing, but the only time this flag
	 * is looked at is after _mesa_program_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void _mesa_program__load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE _mesa_program__create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) _mesa_program_alloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in _mesa_program__create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) _mesa_program_alloc(b->yy_buf_size + 2 ,yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in _mesa_program__create_buffer()" );

	b->yy_is_our_buffer = 1;

	_mesa_program__init_buffer(b,file ,yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with _mesa_program__create_buffer()
 * @param yyscanner The scanner object.
 */
    void _mesa_program__delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		_mesa_program_free((void *) b->yy_ch_buf ,yyscanner );

	_mesa_program_free((void *) b ,yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a _mesa_program_restart() or at EOF.
 */
    static void _mesa_program__init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	_mesa_program__flush_buffer(b ,yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then _mesa_program__init_buffer was _probably_
     * called from _mesa_program_restart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void _mesa_program__flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		_mesa_program__load_buffer_state(yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void _mesa_program_push_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	_mesa_program_ensure_buffer_stack(yyscanner);

	/* This block is copied from _mesa_program__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from _mesa_program__switch_to_buffer. */
	_mesa_program__load_buffer_state(yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void _mesa_program_pop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	_mesa_program__delete_buffer(YY_CURRENT_BUFFER ,yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		_mesa_program__load_buffer_state(yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void _mesa_program_ensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)_mesa_program_alloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in _mesa_program_ensure_buffer_stack()" );
								  
		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)_mesa_program_realloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in _mesa_program_ensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE _mesa_program__scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) _mesa_program_alloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in _mesa_program__scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	_mesa_program__switch_to_buffer(b ,yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to _mesa_program_lex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       _mesa_program__scan_bytes() instead.
 */
YY_BUFFER_STATE _mesa_program__scan_string (yyconst char * yystr , yyscan_t yyscanner)
{
    
	return _mesa_program__scan_bytes(yystr,strlen(yystr) ,yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to _mesa_program_lex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE _mesa_program__scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) _mesa_program_alloc(n ,yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in _mesa_program__scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = _mesa_program__scan_buffer(buf,n ,yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in _mesa_program__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg , yyscan_t yyscanner)
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE _mesa_program_get_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int _mesa_program_get_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int _mesa_program_get_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *_mesa_program_get_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *_mesa_program_get_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
yy_size_t _mesa_program_get_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *_mesa_program_get_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void _mesa_program_set_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void _mesa_program_set_lineno (int  line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "_mesa_program_set_lineno called with no buffer" );
    
    yylineno = line_number;
}

/** Set the current column.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void _mesa_program_set_column (int  column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "_mesa_program_set_column called with no buffer" );
    
    yycolumn = column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see _mesa_program__switch_to_buffer
 */
void _mesa_program_set_in (FILE *  in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = in_str ;
}

void _mesa_program_set_out (FILE *  out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = out_str ;
}

int _mesa_program_get_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void _mesa_program_set_debug (int  bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * _mesa_program_get_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void _mesa_program_set_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

YYLTYPE *_mesa_program_get_lloc  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylloc;
}
    
void _mesa_program_set_lloc (YYLTYPE *  yylloc_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylloc = yylloc_param;
}
    
/* User-visible API */

/* _mesa_program_lex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */

int _mesa_program_lex_init(yyscan_t* ptr_yy_globals)

{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) _mesa_program_alloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* _mesa_program_lex_init_extra has the same functionality as _mesa_program_lex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to _mesa_program_alloc in
 * the yyextra field.
 */

int _mesa_program_lex_init_extra(YY_EXTRA_TYPE yy_user_defined,yyscan_t* ptr_yy_globals )

{
    struct yyguts_t dummy_yyguts;

    _mesa_program_set_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }
	
    *ptr_yy_globals = (yyscan_t) _mesa_program_alloc ( sizeof( struct yyguts_t ), &dummy_yyguts );
	
    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }
    
    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));
    
    _mesa_program_set_extra (yy_user_defined, *ptr_yy_globals);
    
    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from _mesa_program_lex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = 0;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = (char *) 0;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * _mesa_program_lex_init()
     */
    return 0;
}

/* _mesa_program_lex_destroy is for both reentrant and non-reentrant scanners. */
int _mesa_program_lex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		_mesa_program__delete_buffer(YY_CURRENT_BUFFER ,yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		_mesa_program_pop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	_mesa_program_free(yyg->yy_buffer_stack ,yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        _mesa_program_free(yyg->yy_start_stack ,yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * _mesa_program_lex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    _mesa_program_free ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n , yyscan_t yyscanner)
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s , yyscan_t yyscanner)
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *_mesa_program_alloc (yy_size_t  size , yyscan_t yyscanner)
{
	return (void *) malloc( size );
}

void *_mesa_program_realloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void _mesa_program_free (void * ptr , yyscan_t yyscanner)
{
	free( (char *) ptr );	/* see _mesa_program_realloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 494 "program_lexer.l"



void
_mesa_program_lexer_ctor(void **scanner, struct asm_parser_state *state,
			 const char *string, size_t len)
{
   _mesa_program_lex_init_extra(state,scanner);
   _mesa_program__scan_bytes(string,len,*scanner);
}

void
_mesa_program_lexer_dtor(void *scanner)
{
   _mesa_program_lex_destroy(scanner);
}

